<!DOCTYPE html>
<html>
    <head>
        <title>Sebureem installer</title>
    </head>
    <body>
        <h1>Configuration file</h1>

        {% with messages = get_flashed_messages() %}
            {% if messages %}
                <ul class=flashes>
                    {% for message in messages %}
                        <li>{{ message }}</li>
                    {% endfor %}
                </ul>
            {% endif %}
        {% endwith %}
        <p>
            Configuration file location :
            {{ config_path }}
        </p>
        Next step: <a href="{{ url_for('.create_db') }}">Create database</a>
    </body>
</html>
