<!DOCTYPE html>
<html>
    <head>
        <title>Sebureem installer</title>
    </head>
    <body>
        <h1>Sebureem installer</h1>
        Start here<a href="{{ url_for('.create_config') }}">Create configuration file</a>
    </body>
</html>
